#requires -version 2.0

# Jeffery Hicks
# http://jdhitsolutions.com/blog
# follow on Twitter: http://twitter.com/JeffHicks
#
# 
# "Those who forget to script are doomed to repeat their work."

#  ****************************************************************
#  * DO NOT USE IN A PRODUCTION ENVIRONMENT UNTIL YOU HAVE TESTED *
#  * THOROUGHLY IN A LAB ENVIRONMENT. USE AT YOUR OWN RISK.  IF   *
#  * YOU DO NOT UNDERSTAND WHAT THIS SCRIPT DOES OR HOW IT WORKS, *
#  * DO NOT USE IT OUTSIDE OF A SECURE, TEST SETTING.             *
#  ****************************************************************


Param(
[string]$path="$env:userprofile\documents",
[string]$exclude
)

if (Test-Path -path $path) {
    write-host "Collecting file information for $path" -ForegroundColor Green
    
    $files=dir  $path -recurse -Exclude $exclude -errorAction "SilentlyContinue" | where {-not $_.PSIsContainer}
    $stats=$files | Measure-Object -Property Length -sum
    $grouped=$files | group -property Extension

    foreach ($group in $grouped) {
        #measure the total size of each file type
        $measure=$group.group | measure-object -Property length -sum
        
        #calculate % of total size
        $perSize="{0:P4}" -f ($measure.sum/$stats.sum)
        
        #calculate % of total number
        $perTotal="{0:P4}" -f ($measure.count/$stats.count)
        
        #write a custom object to the pipeline
        New-Object -TypeName PSobject -Property @{
            Extension=$group.name
            Total=$group.count
            TotalSizeMB=[Math]::Round($measure.sum/1mb,2)
            PercentTotal=$perTotal
            PercentSize=$perSize
            Files=$group.group
        }
    } #foreach
} #if test-path
else {
    Write-Warning "Failed to find $path"
}

#EOF